/**
 * Copyright (C) 2011 Agrosense <info@cloudfarming.nl>
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package nl.cloudfarming.client.geoviewer.jxmap.render;

import com.vividsolutions.jts.geom.Coordinate;
import com.vividsolutions.jts.geom.MultiLineString;
import java.awt.Color;
import java.awt.Graphics2D;
import java.awt.Rectangle;
import java.awt.geom.Line2D;
import java.awt.geom.Point2D;
import org.jdesktop.swingx.JXMapViewer;
import org.jdesktop.swingx.mapviewer.GeoPosition;
import org.jdesktop.swingx.painter.Painter;

/**
 * Line shape renderer
 * 
 * @author Gerben Feenstra
 */
public class MultiLineStringRenderer extends GeometryRenderer<MultiLineString> {

    public MultiLineStringRenderer() {
    }

    @Override
    public void render(MultiLineString geometry, JXMapViewer mapViewer, Graphics2D graphics) {
        //
        // determine the box the geometry will be drawn in
        //
        Line2D toDraw = new Line2D.Double();
        Coordinate[] coords = geometry.getCoordinates();

        if (coords.length > 1) {

            GeoPosition geopointA = new GeoPosition(coords[0].y, coords[0].x);
            GeoPosition geopointB = new GeoPosition(coords[1].y, coords[1].x);
            Point2D point2DA = mapViewer.getTileFactory().geoToPixel(geopointA, mapViewer.getZoom());
            Point2D point2DB = mapViewer.getTileFactory().geoToPixel(geopointB, mapViewer.getZoom());

            int pointAX = (int) (point2DA.getX() - mapViewer.getViewportBounds().getX());
            int pointAY = (int) (point2DA.getY() - mapViewer.getViewportBounds().getY());
            int pointBX = (int) (point2DB.getX() - mapViewer.getViewportBounds().getX());
            int pointBY = (int) (point2DB.getY() - mapViewer.getViewportBounds().getY());

            toDraw.setLine(pointAX, pointAY, pointBX, pointBY);

        }
        graphics.draw(toDraw);

    }

}
